#include <bits/stdc++.h>
#include <ext/pb_ds/tree_policy.hpp>
#include <ext/pb_ds/assoc_container.hpp>
#include <ext/pb_ds/priority_queue.hpp>

using namespace std;
using namespace __gnu_pbds;

template<typename T>
using ordered_set = tree<T, null_type, less<>, rb_tree_tag, tree_order_statistics_node_update>;

typedef long long ll;

mt19937 rng(chrono::steady_clock::now().time_since_epoch().count());

int random(int l, int r) {
    return uniform_int_distribution<int>(l, r)(rng);
}

struct point {
    int x = 0, y = 0;

    point() = default;

    point(int x, int y): x(x), y(y) {}

    bool operator<(point o) const {
        if (x == o.x) {
            return y < o.y;
        }
        return x < o.x;
    }
};

struct diag {
    int x = 0, y = 0, main = 0;

    diag(int x, int y, int main): x(x), y(y), main(main) {}

    bool operator<(diag o) const {
        if (x == o.x) {
            if (y == o.y) {
                return main < o.main;
            }
            return y < o.y;
        }
        return x < o.x;
    }
};

struct straight {
    int x = 0, y = 0, vert = 0;

    straight(int x, int y, int vert): x(x), y(y), vert(vert) {}

    bool operator<(straight o) const {
        if (x == o.x) {
            if (y == o.y) {
                return vert < o.vert;
            }
            return y < o.y;
        }
        return x < o.x;
    }
};

bool same_diag(diag a, diag b) {
    return a.main == b.main && (a.main ? a.x - b.x == b.y - a.y : a.x - b.x == a.y - b.y);
}

bool same_straight(straight a, straight b) {
    return a.vert == b.vert && (a.vert ? a.x == b.x : a.y == b.y);
}

bool do_intersect_diag(diag a, diag b) {
    return (a.x + a.y) % 2 == (b.x + b.y) % 2 && a.main != b.main;
}

bool do_intersect_straight(straight a, straight b){
    return a.vert != b.vert;
}

point intersect_diag(diag a, diag b) {
    if (a.main) swap(a, b);
    int t = (b.x + b.y - a.x - a.y) / 2;
    return {a.x + t, a.y + t};
}

point intersect_straight(straight a, straight b) {
    if (a.vert) swap(a, b);
    return {b.x, a.y};
}

bool on_diag(diag l, point p) {
    if (l.main) return p.x - l.x == l.y - p.y;
    return p.x - l.x == p.y - l.y;
}

bool on_straight(straight l, point p) {
    if (l.vert) return p.x == l.x;
    return p.y == l.y;
}

point cross_intersect(diag a, straight b) {
    if (b.vert && !a.main) return {b.x, b.x - a.x + a.y};
    if (b.vert && a.main) return {b.x, a.x + a.y - b.x};
    if (!b.vert && a.main) return {a.x + a.y - b.y, b.y};
    if (!b.vert && !a.main) return {b.y + a.x - a.y, b.y};
}

void solve() {
    int n;
    cin >> n;
    vector<point> c(n);
    for (auto &e : c) {
        int x, y;
        cin >> x >> y;
        e = {x, y};
    }
    set<point> points;
    set<diag> diags;
    set<straight> straights;
    auto [x0, y0] = c[0];
    diags.insert({x0, y0, 0});
    diags.insert({x0, y0, 1});
    straights.insert({x0, y0, 0});
    straights.insert({x0, y0, 1});
    points.insert({x0, y0});
    for (int i = 1; i < n; ++i) {
        set<diag> ndiags;
        set<straight> nstraights;
        set<point> npoints;
        diag d {c[i].x, c[i].y, 0};
        for (auto & e : diags) {
            if (same_diag(d, e)) ndiags.insert(e);
            else if (do_intersect_diag(d, e)) {
                npoints.insert(intersect_diag(d, e));
            }
        }
        for (auto &e : straights) {
            npoints.insert(cross_intersect(d, e));
        }
        for (auto &e : points) {
            if (on_diag(d, e)) npoints.insert(e);
        }
        d = {c[i].x, c[i].y, 1};
        for (auto & e : diags) {
            if (same_diag(d, e)) ndiags.insert(e);
            else if (do_intersect_diag(d, e)) {
                npoints.insert(intersect_diag(d, e));
            }
        }
        for (auto &e : straights) {
            npoints.insert(cross_intersect(d, e));
        }
        for (auto &e : points) {
            if (on_diag(d, e)) npoints.insert(e);
        }
        straight s {c[i].x, c[i].y, 0};
        for (auto &e : diags) {
            npoints.insert(cross_intersect(e, s));
        }
        for (auto &e : straights) {
            if (same_straight(e, s)) nstraights.insert(e);
            else if (do_intersect_straight(e, s)) {
                npoints.insert(intersect_straight(s, e));
            }
        }
        for (auto &e : points) {
            if (on_straight(s, e)) npoints.insert(e);
        }
        s = {c[i].x, c[i].y, 1};
        for (auto &e : diags) {
            npoints.insert(cross_intersect(e, s));
        }
        for (auto &e : straights) {
            if (same_straight(e, s)) nstraights.insert(e);
            else if (do_intersect_straight(e, s)) {
                npoints.insert(intersect_straight(s, e));
            }
        }
        for (auto &e : points) {
            if (on_straight(s, e)) npoints.insert(e);
        }
//        map<point, bool> ntake;
//        for (auto &e : npoints) {
//            for (auto &l : ndiags) if (on_diag(l, e)) ntake[e] = 1;
//            for (auto &l : nstraights) if (on_straight(l, e)) ntake[e] = 1;
//        }
        diags = ndiags;
        straights = nstraights;
//        points = {};
//        for (auto &e : npoints) {
//            if (!ntake[e]) points.insert(e);
//        }
        points = npoints;
    }
    if (!points.empty()) {
        cout << "YES" << endl;
        auto p = *points.begin();
        cout << p.x << ' ' << p.y << endl;

    } else {
        cout << "NO" << endl;
    }
}

signed main() {
    int t;
    cin >> t;
    while(t--) {
        solve();
    }
}