#include <bits/stdc++.h>
#include <iostream>

using namespace std;
using ll = int;
using vll = vector<int>;

struct Point {
    ll x, y;

    bool operator==(const Point &o) const {
        return x == o.x && y == o.y;
    }
};

const ll vert = 1e9;

struct Line {
    ll a, b, c;

    Line(ll x0, ll y0, ll _a) {
        if (_a == vert) {
            a = 1;
            b = 0;
            c = -x0;
        } else if (_a == 1) {
            a = 1;
            b = -1;
            c = -x0 + y0;
        } else if (_a == 0) {
            a = 0;
            b = 1;
            c = -y0;
        } else if (_a == -1) {
            a = -1;
            b = -1;
            c = x0 + y0;
        }
    }

    bool is_intersect(Line &o) const {
        ll d = a * o.b - b * o.a;
        if (d == 0) {
            return false;
        }
        ll dx = -c * o.b + o.c * b;
        ll dy = -a * o.c + o.a * c;

        return dx % d == 0 && dy % d == 0;
    }

    bool is_point_on(Point p) {
        return p.x * a + p.y * b + c == 0;
    }

    Point intersect(Line &o) {
        ll d = a * o.b - b * o.a;
        if (d == 0) {
            return {0, 0};
        }
        ll dx = -c * o.b + o.c * b;
        ll dy = -a * o.c + o.a * c;

        ll x = dx / d;
        ll y = dy / d;

        return {x, y};
    }
};

vector<Point> v_q_intersect(vector<Point> v1, Point q2) {
    vector<Line> l2 = {
            {q2.x, q2.y, 0},
            {q2.x, q2.y, 1},
            {q2.x, q2.y, -1},
            {q2.x, q2.y, vert}
    };
    vector<Point> ans;
    for (auto p: v1) {
        for (int i = 0; i < 4; i++) {
            if (l2[i].is_point_on(p)) {
                ans.push_back(p);
            }
        }
    }
    return ans;
}

vector<Point> l_q_intersect(Line l1, Point q2) {
    vector<Line> l2 = {
            {q2.x, q2.y, 0},
            {q2.x, q2.y, 1},
            {q2.x, q2.y, -1},
            {q2.x, q2.y, vert}
    };
    vector<Point> ans;
    for (int i = 0; i < 4; i++) {
        if (l2[i].is_intersect(l1)) {
            ans.push_back(l2[i].intersect(l1));
        }
    }
    return ans;
}

vector<Point> q_q_intersect(Point q1, Point q2) {
    vector<Line> l1 = {
            {q1.x, q1.y, 0},
            {q1.x, q1.y, 1},
            {q1.x, q1.y, -1},
            {q1.x, q1.y, vert}
    };
    vector<Line> l2 = {
            {q2.x, q2.y, 0},
            {q2.x, q2.y, 1},
            {q2.x, q2.y, -1},
            {q2.x, q2.y, vert}
    };

    vector<Point> ans;

    for (int i = 0; i < 4; i++) {
        for (int j = 0; j < 4; j++) {
            if (l1[i].is_intersect(l2[j])) {
                ans.push_back(l1[i].intersect(l2[j]));
            }
        }
    }

    return ans;
}

void printp(const vector<Point> &v) {
    for (auto p: v) {
        cout << p.x << " " << p.y << "\n";
    }
}

void process(vector<Point> &v1, deque<Point> &qs) {
    while (!qs.empty()) {
        v1 = v_q_intersect(v1, qs.front());
        qs.pop_front();
    }
}

vector<Point> process(Line &l1, deque<Point> &qs) {
    Point was_p{};
    while (!qs.empty()) {
        Point q = qs.front();
        was_p = q;
        qs.pop_front();
        if (l1.is_point_on(q)) {
            continue;
        }
        vector v = l_q_intersect(l1, q);
        process(v, qs);
        return v;
    }
    if (l1.is_point_on(was_p))
        return {was_p};
    else
        return {};
}

void Solve() {

    ll n;
    cin >> n;
    deque<Point> qs(n);

    for (int i = 0; i < n; i++) {
        cin >> qs[i].x >> qs[i].y;
    }

    Point q0 = qs[0];
    qs.pop_front();
    if (qs.empty()) {
        cout << "YES\n";
        cout << q0.x << " " << q0.y << "\n";
        return;
    }


    vector<Line> l1 = {
            {q0.x, q0.y, 0},
            {q0.x, q0.y, 1},
            {q0.x, q0.y, -1},
            {q0.x, q0.y, vert}
    };

    for (auto &l: l1) {
        auto qs_copy = qs;
        auto v = process(l, qs_copy);
        if (!v.empty()) {
            cout << "YES\n";
            cout << v[0].x << " " << v[0].y << "\n";
            return;
        }
    }
    cout << "NO\n";
}


signed main() {
    cin.tie(0);
    cout.tie(0);
    ios_base::sync_with_stdio(0);

    ll t;
    cin >> t;
    while (t--) {
        Solve();
    }

    return 0;
}