#include <bits/stdc++.h>

// #pragma GCC optimize("O3")

using namespace std;

bool bit(int mask, int i) {
	return (mask >> i) & 1;
}

struct two_sat {
	int n;
	vector<vector<int>> G, TG;

	two_sat(int n): n(n) {
		G.resize(2 * n);
		TG.resize(2 * n);
	}

	void add_edge(int v, bool f1, int u, bool f2) {
		G[v * 2 + f1].push_back(u * 2 + f2);
		TG[2 * u + f2].push_back(2 * v + f1);
	}

	void add_usl(int v, bool f1, int u, bool f2) {
		// cerr << v << " " << f1 << " " << u << " " << f2 << "\n";

		add_edge(v, !f1, u, f2);
		add_edge(u, !f2, v, f1);
	}

	void add_xor(int v, int u) {
		add_usl(v, true, u, true);
		add_usl(v, false, u, false);
	}

	void add_impl(int v, int u) {
		add_usl(v, false, u, true);
	}

	vector<int> used;
	vector<int> order;

	void dfs(int v) {
		used[v] = true;
		for (int to : G[v]) {
			if (!used[to])
				dfs(to);
		}
		order.push_back(v);
	}

	void dfs2(int v, int c) {
		used[v] = c;
		for (int to : TG[v]) {
			if (used[to] == -1)
				dfs2(to, c);
		}
	}

	vector<int> solve() {
		used.assign(n * 2, false);
		order.clear();
		for (int i = 0; i < 2 * n; i++) {
			if (!used[i])
				dfs(i);
		}
		reverse(order.begin(), order.end());
		used.assign(2 * n, -1);
		int cnt = 0;
		for (int v : order) {
			if (used[v] == -1)
				dfs2(v, cnt++);
		}
		// cerr << "used: ";
		// for (int i : used)
		// 	cerr << i << " ";
		// cerr << "\n";

		for (int i = 0; i < n; i++) {
			if (used[i * 2] == used[2 * i + 1])
				return {};
		}
		vector<int> ans;
		for (int i = 0; i < n; i++) {
			if (used[i * 2] < used[2 * i + 1])
				ans.push_back(i);
		}
		return ans;
	}
};

int n;
vector<int> a;
vector<vector<int>> G;
vector<int> sz;
vector<int> par;

void dfs(int v, int p = -1) {
	sz[v] = 1;
	par[v] = p;
	for (int to : G[v]) {
		if (to != p) {
			dfs(to, v);
			sz[v] += sz[to];
		}
	}
}

void build_sz(int r) {
	sz.resize(2 * n);
	par.resize(2 * n);
	dfs(r);
}

int find_centroid(int v, int p = -1) {
	for (int to : G[v]) {
		if (to == p)
			continue;
		if (sz[to] >= n)
			return find_centroid(to, v);
	}
	return v;
}

int centroid() {
	build_sz(0);
	return find_centroid(0);
}

bool try_solve(int r) {
	vector<pair<int, int>> pos(n, make_pair(-1, -1));
	for (int i = 0; i < 2 * n; i++) {
		int c = a[i];
		if (pos[c].first == -1)
			pos[c].first = i;
		else
			pos[c].second = i;
	}
	build_sz(r);
	two_sat ts(2 * n);
	for (int i = 0; i < n; i++) {
		auto [v, u] = pos[i];
		assert(v != -1 && u != -1);
		ts.add_xor(v, u);
	}
	for (int i = 0; i < 2 * n; i++) {
		if (par[i] != -1) {
			ts.add_impl(i, par[i]);
		}
	}
	vector<int> ans = ts.solve();
	if (!ans.empty()) {
		for (int v : ans)
			cout << v + 1 << " ";
		cout << "\n";
		return true;
	}
	return false;
}

void solve() {
	cin >> n;
	a.resize(2 * n);
	for (int &i : a) {
		cin >> i;
		i--;
	}
	G.assign(2 * n, vector<int>());
	for (int i = 0; i < 2 * n - 1; i++) {
		int v, u;
		cin >> v >> u;
		v--; u--;
		G[v].push_back(u);
		G[u].push_back(v);
	}
	int C = centroid();
	build_sz(C);
	vector<int> maby = {C};
	for (int u : G[C]) {
		if (sz[u] >= n) {
			maby.push_back(u);
		}
	}
	assert(maby.size() <= 2);
	// cerr << "maby: ";
	// for (int i : maby)
	// 	cerr << i << " ";
	// cerr << "\n";

	for (int r : maby) {
		if (try_solve(r))
			return;
	}
	cout << "-1\n";
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	cout.tie(nullptr);

	int T = 1;
	cin >> T;
	while (T--) {
		solve();
	}

	return 0;
}