#include <iostream>
#include <vector>
#include <string>
#include <cstdint>
#include <utility>
#include <cmath>

using namespace std;

using Coordinate = int64_t;

//using Cell = pair<Coordinate, Coordinate>;
struct Cell {
    Coordinate x{0};
    Coordinate y{0};

    bool operator==(const Cell &other) const {
        return (x == other.x) && (y == other.y);
    }

    bool operator!=(const Cell &other) const {
        return !(*this == other);
    }
};

bool under_attack(Cell queen, Cell test) {
    if (queen.x == test.x) {
        return true;
    }
    if (queen.y == test.y) {
        return true;
    }
    if (queen.x - queen.y == test.x - test.y) {
        return true;
    }
    if (queen.x + queen.y == test.x + test.y) {
        return true;
    }
    return false;
}

bool on_hor(Cell c, Coordinate h) {
    return c.y == h;
}

bool on_ver(Cell c, Coordinate v) {
    return c.x == v;
}

bool on_pos_diag(Cell c, Coordinate d) {
    return c.y == c.x + d;
}

bool on_neg_diag(Cell c, Coordinate d) {
    return c.y == -c.x + d;
}

Cell inter_pos_diag_w_hor(Coordinate d, Coordinate h) {
    return {h - d, h};
}

Cell inter_neg_diag_w_hor(Coordinate d, Coordinate h) {
    return {d - h, h};
}

Cell inter_pos_diag_w_ver(Coordinate d, Coordinate v) {
    return {v, v + d};
}

Cell inter_neg_diag_w_ver(Coordinate d, Coordinate v) {
    return {v, d - v};
}

Cell inter_pos_diag_neg_diag(Coordinate d, Coordinate dd) {
    return {(dd - d) / 2, (dd + d) / 2};
}

Cell inter_hor_ver(Coordinate h, Coordinate v) {
    return {v, h};
}

Coordinate get_pos_diag(Cell queen) {
    return queen.y - queen.x;
}

Coordinate get_neg_diag(Cell queen) {
    return queen.y + queen.x;
}

Coordinate get_ver(Cell queen) {
    return queen.x;
}

Coordinate get_hor(Cell queen) {
    return queen.y;
}

int main() {
    cin.tie(nullptr);
    cout.tie(nullptr);
    ios_base::sync_with_stdio(false);

    size_t t;
    cin >> t;
    for (auto test_case = 0; test_case < t; ++test_case) {
        int64_t n;
        cin >> n;

        Cell first;
        cin >> first.x >> first.y;
        n--;

        if (n == 0) {
            cout << "YES" << endl << first.x << ' ' << first.y << endl;
            continue;
        }

        Cell second = first;
        cin >> second.x >> second.y;
        n--;

        if (first.x == second.x) {
            // лежат на одной вертикали x = v
            int64_t v = first.x;
            bool FLAG = true;
            vector<pair<Cell, bool>> extra{{inter_neg_diag_w_hor(get_neg_diag(first), get_hor(second)), true},
                                           {inter_pos_diag_w_hor(get_pos_diag(first), get_hor(second)), true},
                                           {inter_neg_diag_w_hor(get_neg_diag(second), get_hor(first)), true},
                                           {inter_pos_diag_w_hor(get_pos_diag(second), get_hor(first)), true}};
            if ((first.y - second.y) % 2 == 0) {
                extra.emplace_back(inter_pos_diag_neg_diag(get_pos_diag(first), get_neg_diag(second)), true);
                extra.emplace_back(inter_pos_diag_neg_diag(get_pos_diag(second), get_neg_diag(first)), true);
            }

            while (n > 0) {
                Cell current;
                cin >> current.x >> current.y;
                n--;
                if (FLAG && get_ver(current) != v) {
                    FLAG = false;
                    extra.emplace_back(inter_hor_ver(get_hor(current), v), true);
                    extra.emplace_back(inter_pos_diag_w_ver(get_pos_diag(current), v), true);
                    extra.emplace_back(inter_neg_diag_w_ver(get_neg_diag(current), v), true);
                }
                for (auto &e: extra) {
                    if (!under_attack(current, e.first)) { e.second = false; }
                }
            }

            if (FLAG) {
                cout << "YES" << endl << v << ' ' << 0 << endl;
            } else {
                bool found = false;
                for (const auto &[cell, alive]: extra) {
                    if (alive) {
                        found = true;
                        cout << "YES" << endl << cell.x << ' ' << cell.y << endl;
                        break;
                    }
                }
                if (!found) {
                    cout << "NO" << endl;
                }
            }

            continue;
        }

        if (first.y == second.y) {
            // лежат на одной горизонтали y = h
            int64_t h = first.y;
            bool FLAG = true;
            vector<pair<Cell, bool>> extra{{inter_neg_diag_w_ver(get_neg_diag(first), get_ver(second)), true},
                                           {inter_pos_diag_w_ver(get_pos_diag(first), get_ver(second)), true},
                                           {inter_neg_diag_w_ver(get_neg_diag(second), get_ver(first)), true},
                                           {inter_pos_diag_w_ver(get_pos_diag(second), get_ver(first)), true}};
            if ((first.x - second.x) % 2 == 0) {
                extra.emplace_back(inter_pos_diag_neg_diag(get_pos_diag(first), get_neg_diag(second)), true);
                extra.emplace_back(inter_pos_diag_neg_diag(get_pos_diag(second), get_neg_diag(first)), true);
            }

            while (n > 0) {
                Cell current;
                cin >> current.x >> current.y;
                n--;
                if (FLAG && get_hor(current) != h) {
                    FLAG = false;
                    extra.emplace_back(inter_hor_ver(h, get_ver(current)), true);
                    extra.emplace_back(inter_pos_diag_w_hor(get_pos_diag(current), h), true);
                    extra.emplace_back(inter_neg_diag_w_hor(get_neg_diag(current), h), true);
                }
                for (auto &e: extra) {
                    if (!under_attack(current, e.first)) { e.second = false; }
                }
            }

            if (FLAG) {
                cout << "YES" << endl << 0 << ' ' << h << endl;
            } else {
                bool found = false;
                for (const auto &[cell, alive]: extra) {
                    if (alive) {
                        found = true;
                        cout << "YES" << endl << cell.x << ' ' << cell.y << endl;
                        break;
                    }
                }
                if (!found) {
                    cout << "NO" << endl;
                }
            }

            continue;
        }

        if (get_pos_diag(first) == get_pos_diag(second)) {
            int64_t d = get_pos_diag(first);
            bool FLAG = true;
            // лежат на одной диаонали y = x + d
            vector<pair<Cell, bool>> extra{
                    {inter_hor_ver(get_hor(second), get_ver(first)),             true},
                    {inter_hor_ver(get_hor(first), get_ver(second)),             true},
                    {inter_neg_diag_w_ver(get_neg_diag(first), get_ver(second)), true},
                    {inter_neg_diag_w_ver(get_neg_diag(second), get_ver(first)), true},
                    {inter_neg_diag_w_hor(get_neg_diag(first), get_hor(second)), true},
                    {inter_neg_diag_w_hor(get_neg_diag(second), get_hor(first)), true}
            };


            while (n > 0) {
                Cell current;
                cin >> current.x >> current.y;
                n--;
                if (FLAG && get_pos_diag(current) != d) {
                    FLAG = false;
                    extra.emplace_back(inter_pos_diag_w_ver(d, get_ver(current)), true);
                    extra.emplace_back(inter_pos_diag_w_hor(d, get_hor(current)), true);
                    if ((d - get_neg_diag(current)) % 2 == 0) {
                        extra.emplace_back(inter_pos_diag_neg_diag(d, get_neg_diag(current)), true);
                    }
                }
                for (auto &e: extra) {
                    if (!under_attack(current, e.first)) { e.second = false; }
                }
            }

            if (FLAG) {
                cout << "YES" << endl << 0 << ' ' << d << endl;
            } else {
                bool found = false;
                for (const auto &[cell, alive]: extra) {
                    if (alive) {
                        found = true;
                        cout << "YES" << endl << cell.x << ' ' << cell.y << endl;
                        break;
                    }
                }
                if (!found) {
                    cout << "NO" << endl;
                }
            }

            continue;
        }

        if (get_neg_diag(first) == get_neg_diag(second)) {
            int64_t d = get_neg_diag(first);
            bool FLAG = true;
            // лежат на одной диаонали y = -x + d
            vector<pair<Cell, bool>> extra{
                    {inter_hor_ver(get_hor(second), get_ver(first)),             true},
                    {inter_hor_ver(get_hor(first), get_ver(second)),             true},
                    {inter_pos_diag_w_ver(get_pos_diag(first), get_ver(second)), true},
                    {inter_pos_diag_w_ver(get_pos_diag(second), get_ver(first)), true},
                    {inter_pos_diag_w_hor(get_pos_diag(first), get_hor(second)), true},
                    {inter_pos_diag_w_hor(get_pos_diag(second), get_hor(first)), true}
            };

            while (n > 0) {
                Cell current;
                cin >> current.x >> current.y;
                n--;
                if (FLAG && get_neg_diag(current) != d) {
                    FLAG = false;
                    extra.emplace_back(inter_neg_diag_w_ver(d, get_ver(current)), true);
                    extra.emplace_back(inter_neg_diag_w_hor(d, get_hor(current)), true);
                    if ((d - get_pos_diag(current)) % 2 == 0) {
                        extra.emplace_back(inter_pos_diag_neg_diag(get_pos_diag(current), d), true);
                    }
                }
                for (auto &e: extra) {
                    if (!under_attack(current, e.first)) { e.second = false; }
                }
            }

            if (FLAG) {
                cout << "YES" << endl << d << ' ' << 0 << endl;
            } else {
                bool found = false;
                for (const auto &[cell, alive]: extra) {
                    if (alive) {
                        found = true;
                        cout << "YES" << endl << cell.x << ' ' << cell.y << endl;
                        break;
                    }
                }
                if (!found) {
                    cout << "NO" << endl;
                }
            }

            continue;
        }

        vector<pair<Cell, bool>> extra{
                {inter_hor_ver(get_hor(first), get_ver(second)),             true},
                {inter_hor_ver(get_hor(second), get_ver(first)),             true},
                {inter_pos_diag_w_ver(get_pos_diag(first), get_ver(second)), true},
                {inter_pos_diag_w_ver(get_pos_diag(second), get_ver(first)), true},
                {inter_pos_diag_w_hor(get_pos_diag(first), get_hor(second)), true},
                {inter_pos_diag_w_hor(get_pos_diag(second), get_hor(first)), true},
                {inter_neg_diag_w_ver(get_neg_diag(first), get_ver(second)), true},
                {inter_neg_diag_w_ver(get_neg_diag(second), get_ver(first)), true},
                {inter_neg_diag_w_hor(get_neg_diag(first), get_hor(second)), true},
                {inter_neg_diag_w_hor(get_neg_diag(second), get_hor(first)), true}
        };

        if ((get_pos_diag(second) - get_neg_diag(first)) % 2 == 0) {
            extra.emplace_back(
                    inter_pos_diag_neg_diag(get_pos_diag(second), get_neg_diag(first)), true);
        }
        if ((get_pos_diag(first) - get_neg_diag(second)) % 2 == 0) {
            extra.emplace_back(inter_pos_diag_neg_diag(get_pos_diag(first), get_neg_diag(second)), true);
        }

        while (n > 0) {
            Cell current;
            cin >> current.x >> current.y;
            n--;
            for (auto &e: extra) {
                if (!under_attack(current, e.first)) { e.second = false; }
            }
        }

        bool found = false;
        for (const auto &[cell, alive]: extra) {
            if (alive) {
                found = true;
                cout << "YES" << endl << cell.x << ' ' << cell.y << endl;
                break;
            }
        }
        if (!found) {
            cout << "NO" << endl;
        }
    }

    return 0;
}
