#include <bits/stdc++.h>

using namespace std;

using ll = long long;

mt19937 rng(566);

int rnd(int l, int r) {
	return uniform_int_distribution<int>(l, r)(rng);
}

struct SAT {
	int n;
	vector<vector<int>> graph, rgraph;
	vector<int> solution;

	SAT(int n_) : n(n_), graph(2 * n), rgraph(2 * n) {}

	int neg(int x) {
		return x < n ? x + n : x - n;
	}

	void add_impl(int i, int j) {
		graph[i].push_back(j);
		rgraph[j].push_back(i);
		graph[neg(j)].push_back(neg(i));
		rgraph[neg(i)].push_back(neg(j));
	}

	bool solve() {
		vector<bool> used(2 * n);
		vector<int> ts;
		auto dfs1 = [&](auto self, int v) -> void {
			used[v] = 1;
			for (int u : graph[v]) {
				if (!used[u]) self(self, u);
			}
			ts.push_back(v);
		};
		for (int v = 0; v < 2 * n; ++v) {
			if (!used[v]) {
				dfs1(dfs1, v);
			}
		}
		reverse(ts.begin(), ts.end());
		vector<int> comp(2 * n, -1);
		int curcomp = 0;

		auto dfs2 = [&](auto self, int v) -> void {
			comp[v] = curcomp;
			for (int u : rgraph[v]) {
				if (comp[u] < 0) self(self, u);
			}
		};

		for (int v : ts) {
			if (comp[v] < 0) {
				dfs2(dfs2, v);
				curcomp++;
			}
		}

		solution.resize(n);
		for (int v = 0; v < n; ++v) {
			if (comp[v] == comp[v + n]) {
				return false;
			}
			solution[v] = (comp[v] < comp[v + n]);
		}
		return true;
	}
};

void solveTest() {
  int n; cin >> n;
  vector<int> c(2 * n);
  vector<vector<int>> forColor(n);
  for (int i = 0; i < 2 * n; ++i) {
  	cin >> c[i];
  	--c[i];
  	forColor[c[i]].push_back(i);
  }
  vector<vector<int>> graph(2 * n);
  for (int i = 0; i < 2 * n - 1; ++i) {
  	int u, v;
  	cin >> u >> v;
  	--u, --v;
  	graph[u].push_back(v);
  	graph[v].push_back(u);
  }

  auto trySolve = [&](int root) {
  	auto getVar = [&](int v) {
  		int clr = c[v];
  		return clr + n * (v == forColor[clr][1]);
  	};
  	vector<int> par(2 * n, -1);
  	auto dfs = [&](auto self, int v, int p = -1) -> void {
  		par[v] = p;
  		for (int u : graph[v]) {
  			if (u != p) {
  				self(self, u, v);
  			}
  		}
  	};
  	dfs(dfs, root);

  	SAT sat(n);
  	for (int v = 0; v < 2 * n; ++v) {
  		if (v == root) continue;
  		sat.add_impl(getVar(v), getVar(par[v]));
  	}
  	sat.add_impl(sat.neg(getVar(root)), getVar(root));
  	if (sat.solve()) {
  		for (int c = 0; c < n; ++c) {
  			cout << forColor[c][sat.solution[c]] + 1 << ' ';
  		}
  		cout << '\n';
  		return true;
  	}
  	return false;
  };

  int const ITERS = 100;
  for (int iter = 0; iter < ITERS; ++iter) {
  	int root = rnd(0, 2 * n - 1);
  	if (trySolve(root)) return;
  }
  cout << -1 << '\n';
}

int main() {
	ios::sync_with_stdio(false);
	cin.tie(nullptr);
	int t; cin >> t; while (t--) solveTest();
}