#include <bits/stdc++.h>

using namespace std;

using ll = long long;

mt19937 rng(566);

int rnd(int l, int r) {
	return uniform_int_distribution<int>(l, r)(rng);
}

int const N = int(2.1e5);
int solution[N], ts[N], comp[N];
bool used[N];
vector<int> graph[N], rgraph[N];

struct SAT {
	int n;
	int nts;
	int curcomp;
	
	SAT(int n_) : n(n_) {}

	int neg(int x) {
		return x < n ? x + n : x - n;
	}

	void add_impl(int i, int j) {
		graph[i].push_back(j);
		rgraph[j].push_back(i);
		graph[neg(j)].push_back(neg(i));
		rgraph[neg(i)].push_back(neg(j));
	}

	void clear() {
		fill(used, used + 2 * n, 0);
		for (int v = 0; v < 2 * n; ++v) {
			graph[v].clear();
			rgraph[v].clear();
		}
		fill(comp, comp + 2 * n, -1);
		nts = 0;
		curcomp = 0;
	}

	void dfs1(int v) {
		used[v] = 1;
		for (int u : graph[v]) {
			if (!used[u]) dfs1(u);
		}
		ts[nts++] = v;
	}

	void dfs2(int v) {
		comp[v] = curcomp;
		for (int u : rgraph[v]) {
			if (comp[u] < 0) {
				dfs2(u);
			}
		}
	}

	bool solve() {
		for (int v = 0; v < 2 * n; ++v) {
			if (!used[v]) {
				dfs1(v);
			}
		}
		assert(nts == 2 * n);
		reverse(ts, ts + 2 * n);

		for (int i = 0; i < 2 * n; ++i) {
			int v = ts[i];
			if (comp[v] < 0) {
				dfs2(v);
				curcomp++;
			}
		}

		for (int v = 0; v < n; ++v) {
			if (comp[v] == comp[v + n]) {
				return false;
			}
			solution[v] = (comp[v] < comp[v + n]);
		}
		return true;
	}
};

void solveTest() {
  int n;
  n = int(2e5);
  //cin >> n;
  vector<int> c(2 * n);
  vector<vector<int>> forColor(n);
  for (int i = 0; i < 2 * n; ++i) {
  	c[i] = i / 2;
  }
  shuffle(c.begin(), c.end(), rng);
  for (int i = 0; i < 2 * n; ++i) {
  //	cin >> c[i];
  //	--c[i];
  	forColor[c[i]].push_back(i);
  }
  vector<vector<int>> graph(2 * n);
  for (int i = 0; i < 2 * n - 1; ++i) {
  	int u, v;
  	u = i + 2;
  	v = rnd(1, i + 1);
  	//cin >> u >> v;
  	--u, --v;
  	graph[u].push_back(v);
  	graph[v].push_back(u);
  }

  vector<int> par(2 * n, -1);
  SAT sat(n);
  auto trySolve = [&](int root) {
  	auto getVar = [&](int v) {
  		int clr = c[v];
  		return clr + n * (v == forColor[clr][1]);
  	};
  	auto dfs = [&](auto self, int v, int p = -1) -> void {
  		par[v] = p;
  		for (int u : graph[v]) {
  			if (u != p) {
  				self(self, u, v);
  			}
  		}
  	};
  	dfs(dfs, root);

  	sat.clear();
  	for (int v = 0; v < 2 * n; ++v) {
  		if (v == root) continue;
  		sat.add_impl(getVar(v), getVar(par[v]));
  	}
  	sat.add_impl(sat.neg(getVar(root)), getVar(root));
  	if (sat.solve()) {
  		for (int c = 0; c < n; ++c) {
  			cout << forColor[c][solution[c]] + 1 << ' ';
  		}
  		cout << '\n';
  		return true;
  	}
  	return false;
  };

  int const ITERS = 10;
  int const MOD = int(1e9 + 7);
  int a = rnd(1, MOD - 1);
  int cur = rnd(0, MOD - 1);
  for (int iter = 0; iter < ITERS; ++iter) {
  	int root = cur % (2 * n);
  	// int root = rnd(0, 2 * n - 1);
  	if (trySolve(root)) return;
  	cur += a;
  	if (cur >= MOD) cur -= MOD;
  }
  cout << -1 << '\n';
}

int main() {
	ios::sync_with_stdio(false);
	cin.tie(nullptr);
	int t;
	t = 1;
	//cin >> t;
	while (t--) solveTest();
}
